@@ -6,12 +6,12 @@ import numpy as np
 
 class scatter:
 	"""A class that generates basic scatter plots"""
-	def __init__(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
+	def __init__(self, X, Y, title='title', xlabel='xlable', ylabel='ylable', imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
 					ticker_fontsize=9, xTextLoc=None, yTextLoc=None, color='blue', marker='x',
 					xticker_rotate=0, yticker_rotate=0,
 					xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None, 
-					title_font=16, xfont=16, yfont=16, figsize=None):
+					title_font=16, xfont=16, yfont=16, figsize=None, show=True):
 		"""calculates the probability that "token" is found in spam emails
 		
 		:param token: (str)
@@ -21,19 +21,19 @@ class scatter:
 		self.xfont = xfont
 		self.yfont = yfont
 		self.already_called_plot_line = False
-		if subplot is None and figsize is not None: plt.figure(figsize=figsize)
+		if figsize is not None: plt.figure(figsize=figsize)
 
 		self.plot_scatter(X=X, Y=Y, title=title, xlabel=xlabel, ylabel=ylabel, imgText=imgText, outpath=outpath, 
 					subplot=subplot, xlim=xlim, ylim=ylim, xTextShift=xTextShift, yTextShift=yTextShift,
 					ticker_fontsize=ticker_fontsize, xTextLoc=xTextLoc, yTextLoc=yTextLoc, 
 					color=color, marker=marker, xticker_rotate=xticker_rotate, yticker_rotate=yticker_rotate,
 					xtick_locations=xtick_locations, xtick_labels=xtick_labels, 
-					ytick_locations=ytick_locations, ytick_labels=ytick_labels)
+					ytick_locations=ytick_locations, ytick_labels=ytick_labels, show=show)
 
 	def plot_scatter(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
 					ticker_fontsize=9, xTextLoc=None, yTextLoc=None, color='blue', marker='x',
-					xticker_rotate=0, yticker_rotate=0,
+					xticker_rotate=0, yticker_rotate=0, show=True,
 					xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None):
 		"""create a default 2D line plot
 		
@@ -75,11 +75,10 @@ class scatter:
 		if xlim is not None: plt.xlim(xlim)
 		if ylim is not None: plt.ylim(ylim)
 		
-		if subplot is None:
-			if outpath is None: 
-				plt.tight_layout()
-				plt.show()
-			else: plt.savefig(outpath)
+		if subplot is None and outpath is None and show: 
+			plt.tight_layout()
+			plt.show()
+		elif outpath is not None: plt.savefig(outpath)
 
 	def add_text(self, X, Y, textstr, α=0.05, β=0.95, xTextLoc=None, yTextLoc=None):
 		if textstr is None: return
